// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//						(c) 1997 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	LccorrUtils.cc --- lightcurve class
//
//	DESCRIPTION:
//		LccorrUtils
//
//	CHANGE HISTORY:
//		AI, 2007-05-30: 1.0.0: - first version
//
//	AUTHOR:
//		A. Ibarra, Wed May 30 16:32:18 GMT 2007
//
//	REFERENCES:
//
//

#ifndef LCCORRUTILS_H_
#define LCCORRUTILS_H_

#include <vector>
#include <valarray>
#include <list>

#include "Dal.h"
#include "rgsPixelsLib.h"
#include "scanningLib.h"




   using namespace rgsPixelsLib;

	class Accumulator {
	public:
	      list<Span> spans;
	      double exposure;
	      unsigned counts;

	      Accumulator() : exposure(0), counts(0) {}
	      //void select( const ExposureMap&, int column, int offset );
	};

	class SpectralBin {
	   public:
	      struct Accumulator foreground, background;
	      list<Span> bananaSpans;
	      float fullExposure;
	      bool dubious;

	      SpectralBin() : fullExposure(0), dubious(false) {}
	      void fgSpans( const list<Span> &s ) { foreground.spans = s; }
	      void bgSpans( const list<Span> &s ) { background.spans = s; }
	      void phSpans( const list<Span> &s ) { bananaSpans = s; }
	};

	class LccorrUtils
	{
	public:
		 LccorrUtils();
		 //LccorrUtils(const Table *etab);
		~LccorrUtils() {}
		/* AI gcc4 porting
		 * error: extra qualification ‘LccorrUtils::’ on member ‘getRange’
		 * => LccorrUtils:: removed
		 */
		vector<double> getRange(const Column * col);
		vector<double> getRangeInt16(const Column * col);
		void createGrid(double binSize,double starTime, double endTime);
		int getNBins();
		valarray<double> getTimeGrid();

		void createGrids(const Table *etab, string enerUnit);
		void scan( struct Table*);
		void exposureMap( struct Array *array );
		double getArea();
	private:
		void createTimeBins();
		valarray<double> _timeGrid;
		int _nBins;
		struct GridSpan _betaGrid, _xdspGrid;
		double _betaMin, _betaMax;
		double _xdspMin, _xdspMax;
		double _pixels;
		double _areaPerPixel;
	};


#endif /*LCCORRUTILS_H_*/

